==> img0ch-2.1.0.tar.bz2: img0ch/_template/default/t_form.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:BBS_TITLE ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<!--meta.txto͕-->
<?cs if:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
$(function () {
    $("//input[@name='FROM']").val($.cookie("NAME"));
    $("//input[@name='mail']").val($.cookie("MAIL"));
    $("form").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        $.cookie( "NAME", $("//input[@name='FROM']").val(), option );
        $.cookie( "MAIL", $("//input[@name='mail']").val(), option );
        $("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
</head>

<body bgcolor="<?cs if:BBS_BG_COLOR ?>" text="<?cs if:BBS_TEXT_COLOR ?>" link="<?cs if:BBS_LINK_COLOR ?>" alink="<?cs if:BBS_ALINK_COLOR ?>" vlink="<?cs if:BBS_VLINK_COLOR ?>" background="<?cs if:BBS_BG_PICTURE ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs if:BBS_TITLE_LINK ?>"><img src="<?cs if:BBS_TITLE_PICTURE ?>" border="0" /></a><?cs else ?><img src="<?cs if:BBS_TITLE_PICTURE ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<!--[J[̘ggݕ\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs if:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <!--f̃Tu^Cg\-->
      <b><big><?cs if:BBS_SUBTITLE ?></big></b>
     </td>
     <td align=right>
      <a href=#menu></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <!--[J[\-->
      <?cs if:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align="center">
   <!--contents.html̃t[(index.html)ɖ߂郊N̕\-->
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<!--L\-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs if:Banner ?></table><br><?cs /if ?>

<a name="thread" />
<!--XbhVK쐬e[u\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs if:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br><center>
   <form method="POST" action="<?cs if:CGIURI ?>/bbs.cgi" onSubmit="disableSubmit(this)">
   <input type="hidden" name="bbs" value="<?cs if:BBS ?>">
   <input type="hidden" name="time" value="<?cs if:TimeStamp ?>">
    <table border=0>
     <tr>
      <td>
       <!--tH[\-->
        ^CgF<input type="text" name="subject" size="25">@<input type="submit" value="VKXbh쐬"><br>
        O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
       E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
       <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
      </td>
     </tr>
    </table>
   </form>
  </center>
  <?cs var:html_escape(VERSION) ?>
 </td>
</tr>
</table>
</center>
</body>
</html>

==> img0ch-2.1.2.tar.bz2: img0ch/_template/default/t_form.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:BBS_TITLE ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<!--meta.txto͕-->
<?cs if:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form.comment").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
-->
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>

<body bgcolor="<?cs if:BBS_BG_COLOR ?>" text="<?cs if:BBS_TEXT_COLOR ?>" link="<?cs if:BBS_LINK_COLOR ?>" alink="<?cs if:BBS_ALINK_COLOR ?>" vlink="<?cs if:BBS_VLINK_COLOR ?>" background="<?cs if:BBS_BG_PICTURE ?>">

<center>
<a name="top" />
<?cs if:BBS_TITLE_PICTURE ?><?cs if:BBS_TITLE_LINK ?><a href="<?cs if:BBS_TITLE_LINK ?>"><img src="<?cs if:BBS_TITLE_PICTURE ?>" border="0" /></a><?cs else ?><img src="<?cs if:BBS_TITLE_PICTURE ?>" border="0" /><?cs /if ?>
<?cs /if ?>

<a name="info" />
<!--[J[̘ggݕ\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs if:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <table border="0" width="100%">
    <tr>
     <td>
      <!--f̃Tu^Cg\-->
      <b><big><?cs if:BBS_SUBTITLE ?></big></b>
     </td>
     <td align=right>
      <a href=#menu></a> <a href=#1></a>
     </td>
    </tr>
    <tr>
     <td colspan="2">
      <!--[J[\-->
      <?cs if:HEAD ?>
     </td>
    </tr>
   </table>
  </td>
 </tr>
 <tr>
  <td align="center">
   <!--contents.html̃t[(index.html)ɖ߂郊N̕\-->
   <a href="../index.html" Target=_blank><small><b>fꗗ</b></small></a>
  </td>
 </tr>
</table>
<br>

<!--L\-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="#ccffcc" align="center"><?cs if:Banner ?></table><br><?cs /if ?>

<a name="thread" />
<!--XbhVK쐬e[u\-->
<table border="1" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs if:BBS_MENU_COLOR ?>">
 <tr>
  <td>
   <b>XbhVK쐬</b><br><center>
   <form class="comment" method="POST" action="<?cs if:CGIURI ?>/bbs.cgi">
   <input type="hidden" name="bbs" value="<?cs if:BBS ?>">
   <input type="hidden" name="time" value="<?cs if:TimeStamp ?>">
    <table border=0>
     <tr>
      <td>
       <!--tH[\-->
        ^CgF<input type="text" name="subject" size="25">@<input type="submit" value="VKXbh쐬"><br>
        O<font size=1>iȗj</font>F<input type="text" name="FROM" size=19 value="">
       E-mail<font size=1>iȗj</font>F<input type="text" name="mail" size=19 value=""><br>
       <textarea rows=5 cols=64 wrap=off name="MESSAGE"></textarea>
      </td>
     </tr>
    </table>
   </form>
  </center>
  <?cs var:html_escape(VERSION) ?>
 </td>
</tr>
</table>
</center>
</body>
</html>
